@@ -1,12 +1,25 @@
 import datetime
+import warnings
 from pathlib import Path
-from typing import TypedDict
+from typing import NamedTuple, TypedDict
 
 import xarray as xr
 import zarr
 from pyproj import CRS, Transformer
 
 
+class RtcImageSet(TypedDict):
+    VV: Path
+    VH: Path
+
+
+class Bounds(NamedTuple):
+    minx: float
+    miny: float
+    maxx: float
+    maxy: float
+
+
 class ChipDataRequiredOpts(TypedDict):
     strategy: str
     date_start: datetime.datetime
@@ -15,6 +28,15 @@ class ChipDataRequiredOpts(TypedDict):
 
 class ChipDataOpts(ChipDataRequiredOpts, total=False):
     max_cloud_pct: int
+    local_hyp3_paths: dict[str, list[RtcImageSet]]
+
+
+def get_overall_bounds(bounds: list) -> Bounds:
+    minx = min([b[0] for b in bounds])
+    miny = min([b[1] for b in bounds])
+    maxx = max([b[2] for b in bounds])
+    maxy = max([b[3] for b in bounds])
+    return Bounds(minx, miny, maxx, maxy)
 
 
 def get_epsg4326_point(x: float, y: float, in_epsg: int) -> tuple[float, float]:
@@ -39,7 +61,10 @@ def get_epsg4326_bbox(
 def save_chip(dataset: xr.Dataset, save_path: str | Path) -> None:
     """Save a zipped zarr archive"""
     store = zarr.storage.ZipStore(save_path, mode='w')
-    dataset.to_zarr(store)
+    with warnings.catch_warnings():
+        warnings.filterwarnings('ignore', message='Duplicate name:', module='zipfile')
+        dataset.to_zarr(store)  # type: ignore[call-overload]
+    store.close()
 
 
 def load_chip(label_path: str | Path) -> xr.Dataset:
